@@ -1,6 +1,6 @@
 import sys
 
-from shopyoapi.cmd import new_project
+from .shopyoapi.cmd import new_project
 
 def main():
     args = sys.argv
