@@ -1,11 +1,11 @@
 from werkzeug.security import generate_password_hash
 
-from shopyoapi.init import db
-from app import app
+from .init import db
+from ..app import app
 
-from modules.admin.models import User
-from modules.admin.models import Role
-from modules.settings.models import Settings
+from ..modules.admin.models import User
+from ..modules.admin.models import Role
+from ..modules.settings.models import Settings
 
 
 def add_admin(username, password):
